@@ -377,11 +377,13 @@ while(<$fh>){
       outword $xword."", ",";
       $smichut=$xword;
       my $smichut_orig=$xword_orig;
+      unless ($opts{"__"}){
       outword $smichut_orig."-", ",,"; # smichut
+      }
       # (We write patach followed by a consonant yud as "y", and later this will
       # give us the chance to automatically double it as necessary by the
       # Academia's ktiv male rules)
-      unless ($opts{"__"}){
+      unless ($opts{"__"}||$opts{"__"}){
       outword $smichut."y",        ",,/"; # possessives (kinu'im)
       outword $smichut."",      ",,/";
       outword $smichut."",       ",,/";
@@ -408,8 +410,10 @@ while(<$fh>){
       outword $xword."y", ",";
       $smichut=$xword;
       my $smichut_orig=$xword_orig;
-      outword $smichut_orig."-", ",,"; # smichut
       unless ($opts{"__"}){
+      outword $smichut_orig."-", ",,"; # smichut
+      }
+      unless ($opts{"__"}||$opts{"__"}){
       outword $smichut."y",        ",,/"; # possessives (kinu'im)
       outword $smichut."",      ",,/";
       outword $smichut."",       ",,/";
@@ -446,8 +450,10 @@ while(<$fh>){
       }
       
       $smichut=$xword."";
-      outword $smichut."-",   ",,"; # smichut
       unless ($opts{"__"}){
+      outword $smichut."-",   ",,"; # smichut
+      }
+      unless ($opts{"__"}||$opts{"__"}){
       outword $smichut."y",   ",,/"; # possessives (kinu'im)
       outword $smichut."", ",,/";
       outword $smichut."",  ",,/";
@@ -471,8 +477,10 @@ while(<$fh>){
       }
       outword $xword."",   ",";
       $smichut=$xword."";
-      outword $smichut."-",   ",,"; # smichut
       unless ($opts{"__"}){
+      outword $smichut."-",   ",,"; # smichut
+      }
+      unless ($opts{"__"}||$opts{"__"}){
       outword $smichut."y",   ",,/"; # possessives (kinu'im)
       outword $smichut."", ",,/";
       outword $smichut."",  ",,/";
@@ -496,8 +504,10 @@ while(<$fh>){
       }
       outword $xword."",   ",";
       $smichut=$xword."";
-      outword $smichut."-",   ",,"; # smichut
       unless ($opts{"__"}){
+      outword $smichut."-",   ",,"; # smichut
+      }
+      unless ($opts{"__"}||$opts{"__"}){
       outword $smichut."y",   ",,/"; # possessives (kinu'im)
       outword $smichut."", ",,/";
       outword $smichut."",  ",,/";
@@ -526,6 +536,7 @@ while(<$fh>){
       # different ones. This is important for words like , and in fact
       # the _ option does basically the same thing.
       my $smichut_orig;
+      unless ($opts{"__"}){
       if(substr($plural,-2,2) eq ""){
 	$smichut_orig= exists($opts{""}) ? $opts{""} : $plural;
 	# as David Yalin explains (ibid.): "     
@@ -540,9 +551,13 @@ while(<$fh>){
 		substr($opts{""},0,-1) : $smichut;
         outword $smichut_orig."-", ",,"; # smichut
       } else {
-        die "Plural given for $word is of unrecognized form: $plural.";
+        #die "Plural given for $word is of unrecognized form: $plural.";
+	# An unrecognized plural form, so we don't know how to construct the
+	# construct forms from it. Just ignore them.
+	$opts{"__"}=1;
       }
-      unless ($opts{"__"}){
+      }
+      unless ($opts{"__"}||$opts{"__"}){
       outword $smichut."y",        ",,/"; # possessives (kinu'im)
       outword $smichut."",      ",,/";
       outword $smichut."",       ",,/";
@@ -622,20 +637,15 @@ while(<$fh>){
       outword $xword."-", ",,,"; # smichut
     }
     # feminine, singular:
-    if($opts{"_"}){
-      # This is an ad-hoc treatment of the nekeva_it option, which cannot be
-      # combined with others because we will only have one plural form...
-      $xword=$xword."";
-      $opts{"_"}=1;
-    }
     my $nekeva_implicit = !($opts{"_"} || $opts{"_"} ||
-    			    $opts{""});
+    			    $opts{"_"} || $opts{""});
     # by checking for final i, we're basically checking for final  except
     # in final  (see comment above on where we added the i)
     my $nekeva_t = $opts{"_"} ||
     		   ($nekeva_implicit && substr($xword,-2,2) eq "i");
     my $nekeva_h = $opts{"_"} ||
     		   ($nekeva_implicit && !$nekeva_t);
+    my $nekeva_it = $opts{"_"};
     if(exists($opts{""})){
       my $yechida=$opts{""};
       outword $yechida,     ",,";
@@ -661,8 +671,23 @@ while(<$fh>){
       outword $xword."a",  ",,";
       outword $xword."a-", ",,,"; # smichut
     }
-    outword $xword."",  ",,"; # feminine, plural
-    outword $xword."-", ",,,"; # smichut (same as nifrad)
+    if($nekeva_it){
+      outword $xword."",  ",,";
+      outword $xword."-", ",,,"; # smichut
+    }
+    # Feminine, plural:
+    # It stays the same, regardless of the singular for. The only exception
+    # is the  feminine, where the plural becomes . Note that there is
+    # no "else" in the if below - because we need to support the cased that
+    # one word has both types of plural (e.g., see ).
+    if($nekeva_h || $nekeva_t || $opts{""}){
+      outword $xword."",  ",,"; # feminine, plural
+      outword $xword."-", ",,,"; # smichut (same as nifrad)
+    }
+    if($nekeva_it){
+      outword $xword."",  ",,"; # feminine, plural
+      outword $xword."-", ",,,"; # smichut (same as nifrad)
+    }
   } else {
     die "word '".$word."' was not specified as noun, adjective or verb.";
   }
